SingleWebPageController class
- Inheritance
-
- Object
- ChangeNotifier
- ScrollController
- SingleWebPageController
Constructors
-
SingleWebPageController({List<
Snap> snaps = const [], double topSnapExtraOffset = 0, double centerSnapExtraOffset = 0, double bottomSnapExtraOffset = 0, void onAnimatedScrollStart(int currentIndex, int targetIndex)?, void onAnimatedScrollEnd(int currentIndex)?, void onScrollEnd(int lastVisibleIndex)?, bool triggerSameIndexAnimationEffect = true})
Properties
- bottomSnapExtraOffset → double
-
final
- centerSnapExtraOffset → double
-
final
- debugLabel → String?
-
A label that is used in the toString output. Intended to aid with
identifying scroll controller instances in debug output.
finalinherited
- hasClients → bool
-
Whether any ScrollPosition objects have attached themselves to the
ScrollController using the attach method.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- initialScrollOffset → double
-
The initial value to use for offset.
no setterinherited
- keepScrollOffset → bool
-
Each time a scroll completes, save the current scroll offset with
PageStorage and restore it if this controller's scrollable is recreated.
finalinherited
- offset → double
-
The current scroll offset of the scrollable widget.
no setterinherited
- onAnimatedScrollEnd → void Function(int currentIndex)?
-
final
- onAnimatedScrollStart → void Function(int currentIndex, int targetIndex)?
-
final
- onAttach → ScrollControllerCallback?
-
Called when a ScrollPosition is attached to the scroll controller.
finalinherited
- onDetach → ScrollControllerCallback?
-
Called when a ScrollPosition is detached from the scroll controller.
finalinherited
- onScrollEnd → void Function(int lastVisibleIndex)?
-
final
- position → ScrollPosition
-
Returns the attached ScrollPosition, from which the actual scroll offset
of the ScrollView can be obtained.
no setterinherited
-
positions
→ Iterable<
ScrollPosition> -
The currently attached positions.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
snaps
→ List<
Snap> -
final
- topSnapExtraOffset → double
-
final
- triggerSameIndexAnimationEffect → bool
-
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animateTo(
double offset, {required Duration duration, required Curve curve}) → Future< void> -
Animates the position from its current value to the given value.
inherited
-
animateToNextSectionIndex(
{Duration duration = const Duration(milliseconds: 1000), Curve curve = Curves.ease}) → dynamic -
animateToPreviousSectionIndex(
{Duration duration = const Duration(milliseconds: 1000), Curve curve = Curves.ease}) → dynamic -
animateToSectionIndex(
int index, {Duration duration = const Duration(milliseconds: 1000), Curve curve = Curves.ease}) → Future< void> -
attach(
ScrollPosition position) → void -
Register the given position with this controller.
inherited
-
createScrollPosition(
ScrollPhysics physics, ScrollContext context, ScrollPosition? oldPosition) → ScrollPosition -
Creates a ScrollPosition for use by a Scrollable widget.
inherited
-
debugFillDescription(
List< String> description) → void -
Add additional information to the given description for use by toString.
inherited
-
detach(
ScrollPosition position) → void -
Unregister the given position with this controller.
inherited
-
disableScroll(
) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
enableScroll(
) → void -
jumpTo(
double value) → void -
Jumps the scroll position from its current value to the given value,
without animation, and without checking if the new value is in range.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateSectionHeights(
int index, double height) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited